@@ -11,12 +11,22 @@ from numbers import Number
 
 import numpy as np
 
-ALLOWED_ANNOTATION_TYPES = (int, float, complex,
-                            str, bytes,
-                            type(None),
-                            datetime, date, time, timedelta,
-                            Number, Decimal,
-                            np.number, np.bool_)
+ALLOWED_ANNOTATION_TYPES = (
+    int,
+    float,
+    complex,
+    str,
+    bytes,
+    type(None),
+    datetime,
+    date,
+    time,
+    timedelta,
+    Number,
+    Decimal,
+    np.number,
+    np.bool_,
+)
 
 logger = logging.getLogger("Neo")
 
@@ -25,6 +35,29 @@ class MergeError(Exception):
     pass
 
 
+class NeoReadWriteError(IOError):
+    """
+    This is the main neo-specific error that has to deal with
+    ephys data that does not follow the requirements for the Neo
+    object hierarchy.
+
+    It should be used for:
+        1) When an IO does not support a specific read/write functionality
+        2) A file format does not support the structural requirements
+            * Different sampling rates among streams
+            * Different expectations for a file format (could also be
+            a NotImplementedError depending on circumstances)
+
+    It should NOT be used when other errors more accurately describe
+    the problem:
+        1) ValueError: for incorrect values (like t_start, t_stop)
+        2) TypeError: use of an inappropriate type for an argument
+        3) FileNotFoundError: for use when a file is not found
+    """
+
+    pass
+
+
 def _check_annotations(value):
     """
     Recursively check that value is either of a "simple" type (number, string,
@@ -33,17 +66,17 @@ def _check_annotations(value):
     """
     if isinstance(value, np.ndarray):
         if not issubclass(value.dtype.type, ALLOWED_ANNOTATION_TYPES):
-            raise ValueError("Invalid annotation. NumPy arrays with dtype %s"
-                             "are not allowed" % value.dtype.type)
+            raise ValueError(f"Invalid annotation. NumPy arrays with dtype {value.dtype.type}" f"are not allowed")
     elif isinstance(value, dict):
-        for element in value.values():
+        for key, element in value.items():
+            if not isinstance(key, str):
+                raise TypeError(f"Annotations keys must be strings not of type {type(key)}")
             _check_annotations(element)
     elif isinstance(value, (list, tuple)):
         for element in value:
             _check_annotations(element)
     elif not isinstance(value, ALLOWED_ANNOTATION_TYPES):
-        raise ValueError("Invalid annotation. Annotations of type %s are not"
-                         "allowed" % type(value))
+        raise ValueError(f"Invalid annotation. Annotations of type {type(value)} are not" f"allowed")
 
 
 def merge_annotation(a, b):
@@ -58,8 +91,8 @@ def merge_annotation(a, b):
         For strings: concatenate with ';'
         Otherwise: fail if the annotations are not equal
     """
-    assert type(a) == type(b), 'type({}) {} != type({}) {}'.format(a, type(a),
-                                                               b, type(b))
+    if type(a) != type(b):
+        raise TypeError(f"type({a}) {type(a)} != type({b}) {type(b)}")
     if isinstance(a, dict):
         return merge_annotations(a, b)
     elif isinstance(a, np.ndarray):  # concatenate b to a
@@ -72,7 +105,8 @@ def merge_annotation(a, b):
         else:
             return a + ";" + b
     else:
-        assert a == b, '{} != {}'.format(a, b)
+        if a != b:
+            raise ValueError(f"{a} != {b}")
         return a
 
 
@@ -100,7 +134,7 @@ def merge_annotations(A, *Bs):
                     # exc.args += ('key %s' % name,)
                     # raise
                     merged[name] = "MERGE CONFLICT"  # temporary hack
-    logger.debug("Merging annotations: A=%s Bs=%s merged=%s", A, Bs, merged)
+    logger.debug(f"Merging annotations: A={A} Bs={Bs} merged={merged}")
     return merged
 
 
@@ -122,8 +156,8 @@ def intersect_annotations(A, B):
 
     for key in set(A.keys()) & set(B.keys()):
         v1, v2 = A[key], B[key]
-        assert type(v1) == type(v2), 'type({}) {} != type({}) {}'.format(v1, type(v1),
-                                                                         v2, type(v2))
+        if type(v1) != type(v2):
+            raise TypeError(f"type({v1}) {type(v1)} != type({v2}) {type(v2)}")
         if isinstance(v1, dict) and v1 == v2:
             result[key] = deepcopy(v1)
         elif isinstance(v1, str) and v1 == v2:
@@ -156,7 +190,11 @@ def _container_name(class_name):
     referenced by `block.segments`. The attribute name `segments` is
     obtained by calling `_container_name_plural("Segment")`.
     """
-    return _reference_name(class_name) + 's'
+    if "RegionOfInterest" in class_name:
+        # this is a hack, pending a more principled way to handle this
+        return "regionsofinterest"
+    else:
+        return _reference_name(class_name) + "s"
 
 
 class BaseNeo:
@@ -178,7 +216,7 @@ class BaseNeo:
                            class must have. The tuple can have 2-4 elements.
                            The first element is the attribute name.
                            The second element is the attribute type.
-                           The third element is the number of  dimensions
+                           The third element is the number of dimensions
                            (only for numpy arrays and quantities).
                            The fourth element is the dtype of array
                            (only for numpy arrays and quantities).
@@ -245,14 +283,13 @@ class BaseNeo:
     # Attributes that an instance is required to have defined
     _necessary_attrs = ()
     # Attributes that an instance may or may have defined
-    _recommended_attrs = (('name', str),
-                          ('description', str),
-                          ('file_origin', str))
+    _recommended_attrs = (("name", str), ("description", str), ("file_origin", str))
     # Attributes that are used for pretty-printing
     _repr_pretty_attrs_keys_ = ("name", "description", "annotations")
 
-    def __init__(self, name=None, description=None, file_origin=None,
-                 **annotations):
+    is_view = False
+
+    def __init__(self, name=None, description=None, file_origin=None, **annotations):
         """
         This is the base constructor for all Neo objects.
 
@@ -299,7 +336,7 @@ class BaseNeo:
                 else:
                     pp.breakable()
                 with pp.group(indent=1):
-                    pp.text("{}: ".format(key))
+                    pp.text(f"{key}: ")
                     pp.pretty(value)
 
     def _repr_pretty_(self, pp, cycle):
@@ -316,16 +353,14 @@ class BaseNeo:
         """
         Containers for parent objects.
         """
-        return tuple([_reference_name(parent) for parent in
-                      self._parent_objects])
+        return tuple([_reference_name(parent) for parent in self._parent_objects])
 
     @property
     def parents(self):
         """
         All parent objects storing the current object.
         """
-        return tuple([getattr(self, attr) for attr in
-                      self._parent_containers])
+        return tuple([getattr(self, attr) for attr in self._parent_containers])
 
     @property
     def _all_attrs(self):
@@ -348,8 +383,7 @@ class BaseNeo:
             Otherwise: fail if the annotations are not equal
         """
         other_annotations = [other.annotations for other in others]
-        merged_annotations = merge_annotations(self.annotations,
-                                               *other_annotations)
+        merged_annotations = merge_annotations(self.annotations, *other_annotations)
         self.annotations.update(merged_annotations)
 
     def merge(self, *others):
@@ -366,8 +400,12 @@ class BaseNeo:
         according to the type of "obj"
         """
         if obj.__class__.__name__ not in self._parent_objects:
-            raise TypeError("{} can only have parents of type {}, not {}".format(
-                self.__class__.__name__, self._parent_objects, obj.__class__.__name__))
+            raise TypeError(
+                (
+                    f"{self.__class__.__name__} can only have parents of "
+                    f"type {self._parwents_objects}, not {obj.__class__.__name__}"
+                )
+            )
         loc = self._parent_objects.index(obj.__class__.__name__)
         parent_attr = self._parent_attrs[loc]
         setattr(self, parent_attr, obj)
