@@ -6,6 +6,6 @@ class BiocamIO(BiocamRawIO, BaseFromRaw):
     __doc__ = BiocamRawIO.__doc__
     mode = "file"
 
-    def __init__(self, filename):
-        BiocamRawIO.__init__(self, filename=filename)
+    def __init__(self, filename, fill_gaps_strategy=None):
+        BiocamRawIO.__init__(self, filename=filename, fill_gaps_strategy=fill_gaps_strategy)
         BaseFromRaw.__init__(self, filename)
