@@ -3,7 +3,7 @@ from neo.rawio.maxwellrawio import MaxwellRawIO
 
 
 class MaxwellIO(MaxwellRawIO, BaseFromRaw):
-    mode = 'file'
+    mode = "file"
 
     def __init__(self, filename):
         MaxwellRawIO.__init__(self, filename=filename)
