@@ -5,7 +5,8 @@ from neo.core import Segment, AnalogSignal, Epoch, Event
 
 class MicromedIO(MicromedRawIO, BaseFromRaw):
     """Class for reading/writing data from Micromed files (.trc)."""
-    _prefered_signal_group_mode = 'group-by-same-units'
+
+    _prefered_signal_group_mode = "group-by-same-units"
 
     def __init__(self, filename):
         MicromedRawIO.__init__(self, filename=filename)
