@@ -6,10 +6,10 @@ from neo.rawio.nixrawio import NIXRawIO
 
 class NixIO(NIXRawIO, BaseFromRaw):
 
-    name = 'NIX IO'
+    name = "NIX IO"
 
-    _prefered_signal_group_mode = 'group-by-same-units'
-    _prefered_units_group_mode = 'all-in-one'
+    _prefered_signal_group_mode = "group-by-same-units"
+    _prefered_units_group_mode = "all-in-one"
 
     def __init__(self, filename):
         NIXRawIO.__init__(self, filename)
