@@ -3,8 +3,8 @@ from neo.rawio.openephysrawio import OpenEphysRawIO
 
 
 class OpenEphysIO(OpenEphysRawIO, BaseFromRaw):
-    _prefered_signal_group_mode = 'group-by-same-units'
-    mode = 'dir'
+    _prefered_signal_group_mode = "group-by-same-units"
+    mode = "dir"
 
     def __init__(self, dirname):
         OpenEphysRawIO.__init__(self, dirname=dirname)
