@@ -10,14 +10,10 @@ Supported: Read/Write
 Authors: Andrew Davison
 """
 
-try:
-    import cPickle as pickle  # Python 2
-except ImportError:
-    import pickle  # Python 3
+import pickle
 
 from neo.io.baseio import BaseIO
-from neo.core import (Block, Segment,
-                      AnalogSignal, SpikeTrain)
+from neo.core import Block, Segment, AnalogSignal, SpikeTrain, NeoReadWriteError
 
 
 class PickleIO(BaseIO):
@@ -28,6 +24,7 @@ class PickleIO(BaseIO):
     of Neo to that used to create the file. It should therefore not be used for
     long-term storage, but rather for intermediate results in a pipeline.
     """
+
     is_readable = True
     is_writable = True
     has_header = False
@@ -36,12 +33,13 @@ class PickleIO(BaseIO):
     supported_objects = [Block, Segment, AnalogSignal, SpikeTrain]
     readable_objects = supported_objects
     writeable_objects = supported_objects
-    mode = 'file'
+    mode = "file"
     name = "Python pickle file"
-    extensions = ['pkl', 'pickle']
+    extensions = ["pkl", "pickle"]
 
     def read_block(self, lazy=False):
-        assert not lazy, 'Do not support lazy'
+        if lazy:
+            raise NeoReadWriteError("This IO does not support lazy reading")
         with open(self.filename, "rb") as fp:
             block = pickle.load(fp)
         return block
