@@ -26,6 +26,8 @@ Based on exampleio.py and axonio.py from neo.io
 08 Feb 2014, C. Schmidt-Hieber, University College London
 """
 
+import importlib.util
+
 import numpy as np
 import quantities as pq
 
@@ -92,7 +94,9 @@ class StimfitIO(BaseIO):
         """
         # We need this module, so try importing now so that it fails on
         # instantiation rather than read_block
-        import stfio  # noqa
+        stfio_spec = importlib.util.find_spec("stfio")
+        if stfio_spec is None:
+            raise ImportError("stfio must be installed to use StimfitIO")
 
         BaseIO.__init__(self)
 
