@@ -11,8 +11,9 @@ class TdtIO(TdtRawIO, BaseFromRaw):
     (sub directories).
     Tanks correspond to Neo Blocks and TDT blocks correspond to Neo Segments.
     """
-    _prefered_signal_group_mode = 'group-by-same-units'
-    mode = 'dir'
+
+    _prefered_signal_group_mode = "group-by-same-units"
+    mode = "dir"
 
     def __init__(self, dirname):
         TdtRawIO.__init__(self, dirname=dirname)
