@@ -17,6 +17,7 @@ from .baserawio import (
     BaseRawIO,
     _signal_channel_dtype,
     _signal_stream_dtype,
+    _signal_buffer_dtype,
     _spike_channel_dtype,
     _event_channel_dtype,
 )
@@ -93,8 +94,10 @@ class MEArecRawIO(BaseRawIO):
         self._num_channels = self.channel_positions.shape[0]
         self._dtype = self.info_dict["recordings"]["dtype"]
 
-        signals = [("Signals", "0")] if self.load_analogsignal else []
-        signal_streams = np.array(signals, dtype=_signal_stream_dtype)
+        signal_buffers = [("Signals", "0")] if self.load_analogsignal else []
+        signal_streams = [("Signals", "0", "0")] if self.load_analogsignal else []
+        signal_streams = np.array(signal_streams, dtype=_signal_stream_dtype)
+        signal_buffers = np.array(signal_buffers, dtype=_signal_buffer_dtype)
 
         sig_channels = []
         if self.load_analogsignal:
@@ -107,7 +110,8 @@ class MEArecRawIO(BaseRawIO):
                 gain = 1.0
                 offset = 0.0
                 stream_id = "0"
-                sig_channels.append((ch_name, chan_id, sr, dtype, units, gain, offset, stream_id))
+                buffer_id = "0"
+                sig_channels.append((ch_name, chan_id, sr, dtype, units, gain, offset, stream_id, buffer_id))
 
         sig_channels = np.array(sig_channels, dtype=_signal_channel_dtype)
 
@@ -135,6 +139,7 @@ class MEArecRawIO(BaseRawIO):
         self.header = {}
         self.header["nb_block"] = 1
         self.header["nb_segment"] = [1]
+        self.header["signal_buffers"] = signal_buffers
         self.header["signal_streams"] = signal_streams
         self.header["signal_channels"] = sig_channels
         self.header["spike_channels"] = spike_channels
