@@ -31,6 +31,7 @@ from .baserawio import (
     BaseRawIO,
     _signal_channel_dtype,
     _signal_stream_dtype,
+    _signal_buffer_dtype,
     _spike_channel_dtype,
     _event_channel_dtype,
 )
@@ -96,7 +97,8 @@ class NeuroExplorerRawIO(BaseRawIO):
                 gain = entity_header["ADtoMV"]
                 offset = entity_header["MVOffset"]
                 stream_id = str(_id)
-                sig_channels.append((name, _id, sampling_rate, dtype, units, gain, offset, stream_id))
+                buffer_id = ""
+                sig_channels.append((name, _id, sampling_rate, dtype, units, gain, offset, stream_id, buffer_id))
                 self._sig_lengths.append(entity_header["NPointsWave"])
                 # sig t_start is the first timestamp if datablock
                 offset = entity_header["offset"]
@@ -112,16 +114,19 @@ class NeuroExplorerRawIO(BaseRawIO):
         event_channels = np.array(event_channels, dtype=_event_channel_dtype)
 
         # each signal channel has different groups that force reading
-        # them one by one
+        # them one by one so one stream per channel and no buffer
         sig_channels["stream_id"] = np.arange(sig_channels.size).astype("U")
         signal_streams = np.zeros(sig_channels.size, dtype=_signal_stream_dtype)
         signal_streams["name"] = sig_channels["name"]
         signal_streams["id"] = sig_channels["stream_id"]
+        signal_streams["buffer_id"] = ""
+        signal_buffers = np.array([], dtype=_signal_buffer_dtype)
 
         # fill into header dict
         self.header = {}
         self.header["nb_block"] = 1
         self.header["nb_segment"] = [1]
+        self.header["signal_buffers"] = signal_buffers
         self.header["signal_streams"] = signal_streams
         self.header["signal_channels"] = sig_channels
         self.header["spike_channels"] = spike_channels
