@@ -53,6 +53,7 @@ Some functions are copied from Graham Findlay
 from pathlib import Path
 import os
 import re
+from warnings import warn
 
 import numpy as np
 
@@ -76,7 +77,9 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
     dirname: str, default: ''
         The spikeglx folder containing meta/bin files
     load_sync_channel: bool, default: False
-        The last channel (SY0) of each stream is a fake channel used for synchronisation
+        Can be used to load the synch stream as the last channel of the neural data.
+        This option is deprecated and will be removed in version 0.15.
+        From versions higher than 0.14.1 the sync channel is always loaded as a separate stream.
     load_channel_location: bool, default: False
         If True probeinterface is used to load the channel locations from the directory
 
@@ -109,6 +112,13 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
         BaseRawWithBufferApiIO.__init__(self)
         self.dirname = dirname
         self.load_sync_channel = load_sync_channel
+        if load_sync_channel:
+            warn(
+                "The load_sync_channel=True option is deprecated and will be removed in version 0.15 \n"
+                "The sync channel is now loaded as a separate stream by default and should be accessed as such. ",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         self.load_channel_location = load_channel_location
 
     def _source_name(self):
@@ -116,6 +126,7 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
 
     def _parse_header(self):
         self.signals_info_list = scan_files(self.dirname)
+        _add_segment_order(self.signals_info_list)
 
         # sort stream_name by higher sampling rate first
         srates = {info["stream_name"]: info["sampling_rate"] for info in self.signals_info_list}
@@ -152,9 +163,12 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
         signal_buffers = []
         signal_streams = []
         signal_channels = []
+        sync_stream_id_to_buffer_id = {}
+
         for stream_name in stream_names:
-            # take first segment
-            info = self.signals_info_dict[0, stream_name]
+            # take first segment to extract the signal info
+            segment_index = 0
+            info = self.signals_info_dict[segment_index, stream_name]
 
             buffer_id = stream_name
             buffer_name = stream_name
@@ -164,10 +178,22 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
 
             signal_streams.append((stream_name, stream_id, buffer_id))
 
-            # add channels to global list
-            for local_chan in range(info["num_chan"]):
-                chan_name = info["channel_names"][local_chan]
+            # add channels to signal channel header
+            for local_channel_index in range(info["num_chan"]):
+                chan_name = info["channel_names"][local_channel_index]
                 chan_id = f"{stream_name}#{chan_name}"
+
+                # Separate sync channel in its own stream
+                is_sync_channel = "SY" in chan_name and not self.load_sync_channel
+                if is_sync_channel:
+                    # This is a sync channel and should be added as its own stream
+                    sync_stream_id = f"{stream_name}-SYNC"
+                    sync_stream_id_to_buffer_id[sync_stream_id] = buffer_id
+                    stream_id_for_chan = sync_stream_id
+
+                else:
+                    stream_id_for_chan = stream_id
+
                 signal_channels.append(
                     (
                         chan_name,
@@ -175,27 +201,36 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
                         info["sampling_rate"],
                         "int16",
                         info["units"],
-                        info["channel_gains"][local_chan],
-                        info["channel_offsets"][local_chan],
-                        stream_id,
+                        info["channel_gains"][local_channel_index],
+                        info["channel_offsets"][local_channel_index],
+                        stream_id_for_chan,
                         buffer_id,
                     )
                 )
 
-            # all channel by dafult unless load_sync_channel=False
+            # None here means that the all the channels in the buffer will be included
             self._stream_buffer_slice[stream_id] = None
-            # check sync channel validity
+
+            # Then we modify this if sync channel is present to slice the last channel
+            # out of the stream buffer
             if "nidq" not in stream_name:
                 if not self.load_sync_channel and info["has_sync_trace"]:
-                    # the last channel is remove from the stream but not from the buffer
-                    last_chan = signal_channels[-1]
-                    last_chan = last_chan[:-2] + ("", buffer_id)
-                    signal_channels = signal_channels[:-1] + [last_chan]
+                    # the last channel is removed from the stream but not from the buffer
                     self._stream_buffer_slice[stream_id] = slice(0, -1)
+
+                    # Add a buffer slice for the sync channel
+                    sync_stream_id = f"{stream_name}-SYNC"
+                    self._stream_buffer_slice[sync_stream_id] = slice(-1, None)
+
                 if self.load_sync_channel and not info["has_sync_trace"]:
                     raise ValueError("SYNC channel is not present in the recording. " "Set load_sync_channel to False")
 
         signal_buffers = np.array(signal_buffers, dtype=_signal_buffer_dtype)
+
+        # Add sync channels as their own streams. We do it here to keep the order of the streams
+        for sync_stream_id, buffer_id in sync_stream_id_to_buffer_id.items():
+            signal_streams.append((sync_stream_id, sync_stream_id, buffer_id))
+
         signal_streams = np.array(signal_streams, dtype=_signal_stream_dtype)
         signal_channels = np.array(signal_channels, dtype=_signal_channel_dtype)
 
@@ -211,12 +246,20 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
                         chan_name = local_chan
                         chan_id = f"{stream_name}#{chan_name}"
                         event_channels.append((chan_name, chan_id, "event"))
-                    # add events_memmap
-                    data = np.memmap(info["bin_file"], dtype="int16", mode="r", offset=0, order="C")
-                    data = data.reshape(-1, info["num_chan"])
-                    # The digital word is usually the last channel, after all the individual analog channels
-                    extracted_word = data[:, len(info["analog_channels"])]
-                    self._events_memmap = np.unpackbits(extracted_word.astype(np.uint8)[:, None], axis=1)
+                    # Create memmap for digital word but defer unpacking until needed
+                    # The digital word is stored as the last channel, after all the individual analog channels
+                    # For example: if there are 8 analog channels (indices 0-7), the digital word is at index 8
+                    num_samples = info["sample_length"]
+                    num_channels = info["num_chan"]
+                    data = np.memmap(
+                        info["bin_file"],
+                        dtype="int16",
+                        mode="r",
+                        shape=(num_samples, num_channels),
+                        order="C",
+                    )
+                    digital_word_channel_index = len(info["analog_channels"])
+                    self._events_memmap_digital_word = data[:, digital_word_channel_index]
         event_channels = np.array(event_channels, dtype=_event_channel_dtype)
 
         # No spikes
@@ -224,7 +267,6 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
         spike_channels = np.array(spike_channels, dtype=_spike_channel_dtype)
 
         # deal with nb_segment and t_start/t_stop per segment
-
         self._t_starts = {stream_name: {} for stream_name in stream_names}
         self._t_stops = {seg_index: 0.0 for seg_index in range(nb_segment)}
 
@@ -237,6 +279,14 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
                 t_start = frame_start / sampling_frequency
 
                 self._t_starts[stream_name][seg_index] = t_start
+
+                # This need special logic because sync not present in stream_names
+                if f"{stream_name}-SYNC" in signal_streams["name"]:
+                    sync_stream_name = f"{stream_name}-SYNC"
+                    if sync_stream_name not in self._t_starts:
+                        self._t_starts[sync_stream_name] = {}
+                    self._t_starts[sync_stream_name][seg_index] = t_start
+
                 t_stop = info["sample_length"] / info["sampling_rate"]
                 self._t_stops[seg_index] = max(self._t_stops[seg_index], t_stop)
 
@@ -266,6 +316,10 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
                     # need probeinterface to be installed
                     import probeinterface
 
+                    # Skip for sync streams
+                    if "SYNC" in stream_name:
+                        continue
+
                     info = self.signals_info_dict[seg_index, stream_name]
                     if "imroTbl" in info["meta"] and info["stream_kind"] == "ap":
                         # only for ap channel
@@ -296,7 +350,9 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
         info = self.signals_info_dict[0, "nidq"]  # There are no events that are not in the nidq stream
         dig_ch = info["digital_channels"]
         if len(dig_ch) > 0:
-            event_data = self._events_memmap
+            # Unpack bits on-demand - this is when memory allocation happens
+            event_data = np.unpackbits(self._events_memmap_digital_word.astype(np.uint8)[:, None], axis=1)
+
             channel = dig_ch[event_channel_index]
             ch_idx = 7 - int(channel[2:])  # They are in the reverse order
             this_stream = event_data[:, ch_idx]
@@ -331,12 +387,7 @@ class SpikeGLXRawIO(BaseRawWithBufferApiIO):
 
 def scan_files(dirname):
     """
-    Scan for pairs of `.bin` and `.meta` files and return information about it.
-
-    After exploring the folder, the segment index (`seg_index`) is construct as follow:
-      * if only one `gate_num=0` then `trigger_num` = `seg_index`
-      * if only one `trigger_num=0` then `gate_num` = `seg_index`
-      * if both are increasing then seg_index increased by gate_num, trigger_num order.
+    Scan for pairs of `.bin` and `.meta` files and parse the metadata file to extract signal information.
     """
     info_list = []
 
@@ -346,6 +397,7 @@ def scan_files(dirname):
                 continue
             meta_filename = Path(root) / file
             bin_filename = meta_filename.with_suffix(".bin")
+
             if meta_filename.exists() and bin_filename.exists():
                 meta = read_meta_file(meta_filename)
                 info = extract_stream_info(meta_filename, meta)
@@ -357,6 +409,19 @@ def scan_files(dirname):
     if len(info_list) == 0:
         raise FileNotFoundError(f"No appropriate combination of .meta and .bin files were detected in {dirname}")
 
+    return info_list
+
+
+def _add_segment_order(info_list):
+    """
+    Uses gate and trigger numbers to construct a segment index (`seg_index`) for each signal in `info_list`.
+
+    After exploring the folder, the segment index (`seg_index`) is construct as follow:
+      * if only one `gate_num=0` then `trigger_num` = `seg_index`
+      * if only one `trigger_num=0` then `gate_num` = `seg_index`
+      * if both are increasing then seg_index increased by gate_num, trigger_num order.
+
+    """
     # This sets non-integers values before integers
     normalize = lambda x: x if isinstance(x, int) else -1
 
@@ -376,38 +441,6 @@ def scan_files(dirname):
     for info in info_list:
         info["seg_index"] = segment_tuple_to_segment_index[get_segment_tuple(info)]
 
-    # Probe index calculation
-    # The calculation is ordered by slot, port, dock in that order, this is the number that appears in the filename
-    # after imec when using native names (e.g. imec0, imec1, etc.)
-    def get_probe_tuple(info):
-        slot = normalize(info.get("probe_slot"))
-        port = normalize(info.get("probe_port"))
-        dock = normalize(info.get("probe_dock"))
-        return (slot, port, dock)
-
-    # TODO: handle one box case
-    info_list_imec = [info for info in info_list if info.get("device") != "nidq"]
-    unique_probe_tuples = {get_probe_tuple(info) for info in info_list_imec}
-    sorted_probe_keys = sorted(unique_probe_tuples)
-    probe_tuple_to_probe_index = {key: idx for idx, key in enumerate(sorted_probe_keys)}
-
-    for info in info_list:
-        if info.get("device") == "nidq":
-            info["device_index"] = ""  # TODO: Handle multi nidq case, maybe use meta["typeNiEnabled"]
-        else:
-            info["device_index"] = probe_tuple_to_probe_index[get_probe_tuple(info)]
-
-    # Define stream base on device [imec|nidq], device_index and stream_kind [ap|lf] for imec
-    for info in info_list:
-        device_kind = info["device_kind"]
-        device_index = info["device_index"]
-        stream_kind = f".{info['stream_kind']}" if info["stream_kind"] else ""
-        stream_name = f"{device_kind}{device_index}{stream_kind}"
-
-        info["stream_name"] = stream_name
-
-    return info_list
-
 
 def parse_spikeglx_fname(fname):
     """
@@ -417,13 +450,13 @@ def parse_spikeglx_fname(fname):
     https://github.com/billkarsh/SpikeGLX/blob/15ec8898e17829f9f08c226bf04f46281f106e5f/Markdown/UserManual.md#gates-and-triggers
 
     Example file name structure:
-    Consider the filenames: `Noise4Sam_g0_t0.nidq.bin` or `Noise4Sam_g0_t0.imec0.lf.bin`
+    Consider the filenames: `Noise4Sam_g0_t0.nidq.bin`, `Noise4Sam_g0_t0.imec0.lf.bin`, or `myRun_g0_t0.obx0.obx.bin`
     The filenames consist of 3 or 4 parts separated by `.`
     1. "Noise4Sam_g0_t0" will be the `name` variable. This choosen by the user at recording time.
     2. "g0" is the "gate_num"
     3. "t0" is the "trigger_num"
-    4. "nidq" or "imec0" will give the `device`
-    5. "lf" or "ap" will be the `stream_kind`
+    4. "nidq", "imec0", or "obx0" will give the `device`
+    5. "lf", "ap", or "obx" will be the `stream_kind`
        `stream_name` variable is the concatenation of `device.stream_kind`
 
     If CatGT is used, then the trigger numbers in the file names ("t0"/"t1"/etc.)
@@ -438,7 +471,7 @@ def parse_spikeglx_fname(fname):
     Parameters
     ---------
     fname: str
-        The filename to parse without the extension, e.g. "my-run-name_g0_t1.imec2.lf"
+        The filename to parse without the extension, e.g. "my-run-name_g0_t1.imec2.lf" or "my-run-name_g0_t0.obx0.obx"
 
     Returns
     -------
@@ -449,45 +482,86 @@ def parse_spikeglx_fname(fname):
     trigger_num: int | str or None
         The trigger identifier, e.g. 1. If CatGT is used, then the trigger_num will be set to "cat".
     device: str
-        The probe identifier, e.g. "imec2"
+        The probe identifier, e.g. "imec2" or "obx0"
     stream_kind: str or None
-        The data type identifier, "lf" or "ap" or None
+        The data type identifier, "lf", "ap", "obx", or None
     """
-    re_standard = re.findall(r"(\S*)_g(\d*)_t(\d*)\.(\S*).(ap|lf)", fname)
-    re_tcat = re.findall(r"(\S*)_g(\d*)_tcat.(\S*).(ap|lf)", fname)
-    re_nidq = re.findall(r"(\S*)_g(\d*)_t(\d*)\.(\S*)", fname)
-    if len(re_standard) == 1:
-        # standard case with probe
-        run_name, gate_num, trigger_num, device, stream_kind = re_standard[0]
-    elif len(re_tcat) == 1:
-        # tcat case
-        run_name, gate_num, device, stream_kind = re_tcat[0]
-        trigger_num = "cat"
-    elif len(re_nidq) == 1:
-        # case for nidaq
-        run_name, gate_num, trigger_num, device = re_nidq[0]
-        stream_kind = None
-    else:
-        # the naming do not correspond lets try something more easy
-        # example: sglx_xxx.imec0.ap
-        re_else = re.findall(r"(\S*)\.(\S*).(ap|lf)", fname)
-        re_else_nidq = re.findall(r"(\S*)\.(\S*)", fname)
-        if len(re_else) == 1:
-            run_name, device, stream_kind = re_else[0]
-            gate_num, trigger_num = None, None
-        elif len(re_else_nidq) == 1:
-            # easy case for nidaq, example: sglx_xxx.nidq
-            run_name, device = re_else_nidq[0]
-            gate_num, trigger_num, stream_kind = None, None, None
-        else:
-            raise ValueError(f"Cannot parse filename {fname}")
 
-    if gate_num is not None:
-        gate_num = int(gate_num)
-    if trigger_num is not None and trigger_num != "cat":
-        trigger_num = int(trigger_num)
+    # Standard case: contains gate, trigger, device, and stream kind
+    # Example: Noise4Sam_g0_t0.imec0.ap
+    # Format:  {run_name}_g{gate_num}_t{trigger_num}.{device}.{stream_kind}
+    # Regex tokens:
+    #   \S+         → one or more non-whitespace characters
+    #   \d+         → one or more digits
+    #   ap|lf       → either 'ap' or 'lf'
+    regex = r"(?P<run_name>\S+)_g(?P<gate_num>\d+)_t(?P<trigger_num>\d+)\.(?P<device>\S+)\.(?P<stream_kind>ap|lf)"
+    match = re.match(regex, fname)
+    if match:
+        gd = match.groupdict()
+        return gd["run_name"], int(gd["gate_num"]), int(gd["trigger_num"]), gd["device"], gd["stream_kind"]
 
-    return (run_name, gate_num, trigger_num, device, stream_kind)
+    # CatGT case: trigger renamed to 'tcat'
+    # Example: Noise4Sam_g0_tcat.imec0.ap
+    # Format:  {run_name}_g{gate_num}_tcat.{device}.{stream_kind}
+    # Regex tokens:
+    #   \S+         → one or more non-whitespace characters
+    #   \d+         → one or more digits
+    #   ap|lf       → either 'ap' or 'lf'
+    regex = r"(?P<run_name>\S+)_g(?P<gate_num>\d+)_tcat\.(?P<device>\S+)\.(?P<stream_kind>ap|lf)"
+    match = re.match(regex, fname)
+    if match:
+        gd = match.groupdict()
+        return gd["run_name"], int(gd["gate_num"]), "cat", gd["device"], gd["stream_kind"]
+
+    # OneBox case: ends in .obx
+    # Example: myRun_g0_t0.obx0.obx
+    # Format:  {run_name}_g{gate_num}_t{trigger_num}.{device}.obx
+    # Regex tokens:
+    #   \S+         → one or more non-whitespace characters
+    #   \d+         → one or more digits
+    regex = r"(?P<run_name>\S+)_g(?P<gate_num>\d+)_t(?P<trigger_num>\d+)\.(?P<device>\S+)\.obx"
+    match = re.match(regex, fname)
+    if match:
+        gd = match.groupdict()
+        return gd["run_name"], int(gd["gate_num"]), int(gd["trigger_num"]), gd["device"], "obx"
+
+    # NIDQ case no stream kind (not ap or lf)
+    # Example: Noise4Sam_g0_t0.nidq
+    # Format:  {run_name}_g{gate_num}_t{trigger_num}.{device}
+    # Regex tokens:
+    #   \S+         → one or more non-whitespace characters
+    #   \d+         → one or more digits
+    regex = r"(?P<run_name>\S+)_g(?P<gate_num>\d+)_t(?P<trigger_num>\d+)\.(?P<device>\S+)"
+    match = re.match(regex, fname)
+    if match:
+        gd = match.groupdict()
+        return gd["run_name"], int(gd["gate_num"]), int(gd["trigger_num"]), gd["device"], None
+
+    # Fallback case 1): no gate/trigger, includes device and stream kind
+    # Example: sglx_name.imec0.ap
+    # Format:  {run_name}.{device}.{stream_kind}
+    # Regex tokens:
+    #   \S+         → one or more non-whitespace characters
+    #   ap|lf       → either 'ap' or 'lf'
+    regex = r"(?P<run_name>\S+)\.(?P<device>\S+)\.(?P<stream_kind>ap|lf)"
+    match = re.match(regex, fname)
+    if match:
+        gd = match.groupdict()
+        return gd["run_name"], None, None, gd["device"], gd["stream_kind"]
+
+    # Fallback NIDQ-style: no stream kind
+    # Example: sglx_name.nidq
+    # Format:  {run_name}.{device}
+    # Regex tokens:
+    #   \S+         → one or more non-whitespace characters
+    regex = r"(?P<run_name>\S+)\.(?P<device>\S+)"
+    match = re.match(regex, fname)
+    if match:
+        gd = match.groupdict()
+        return gd["run_name"], None, None, gd["device"], None
+
+    # No known pattern matched
+    raise ValueError(f"Cannot parse filename {fname}")
 
 
 def read_meta_file(meta_file):
@@ -520,12 +594,17 @@ def extract_stream_info(meta_file, meta):
         # AP and LF meta have this field
         ap, lf, sy = [int(s) for s in meta["snsApLfSy"].split(",")]
         has_sync_trace = sy == 1
+    elif "snsXaDwSy" in meta:
+        # OneBox case
+        xa, dw, sy = [int(s) for s in meta["snsXaDwSy"].split(",")]
+        has_sync_trace = sy == 1
     else:
         # NIDQ case
         has_sync_trace = False
 
-    bin_file_path = meta["fileName"]
-    fname = Path(bin_file_path).stem
+    # This is the original name that the file had. It might not match the current name if the user changed it
+    original_bin_file_path = meta["fileName"]
+    fname = Path(original_bin_file_path).stem
 
     run_name, gate_num, trigger_num, device, stream_kind = parse_spikeglx_fname(fname)
 
@@ -541,7 +620,7 @@ def extract_stream_info(meta_file, meta):
         if (
             "imDatPrb_type" not in meta
             or meta["imDatPrb_type"] == "0"
-            or meta["imDatPrb_type"] in ("1015", "1016", "1022", "1030", "1031", "1032", "1100", "1121", "1300")
+            or meta["imDatPrb_type"] in ("1015", "1016", "1022", "1030", "1031", "1032", "1100", "1121", "1123", "1300")
         ):
             # This work with NP 1.0 case with different metadata versions
             # https://github.com/billkarsh/SpikeGLX/blob/15ec8898e17829f9f08c226bf04f46281f106e5f/Markdown/Metadata_30.md
@@ -568,6 +647,18 @@ def extract_stream_info(meta_file, meta):
             channel_gains = gain_factor * per_channel_gain * 1e6
         else:
             raise NotImplementedError("This meta file version of spikeglx" " is not implemented")
+    elif meta.get("typeThis") == "obx":
+        # OneBox case
+        device = fname.split(".")[-2] if "." in fname else device
+        stream_kind = ""
+        units = "V"
+
+        # OneBox gain calculation
+        # V = i * Vmax / Imax where Imax = obMaxInt, Vmax = obAiRangeMax
+        # See: https://billkarsh.github.io/SpikeGLX/Sgl_help/Metadata_30.html
+        max_int = int(meta["obMaxInt"])
+        gain_factor = float(meta["obAiRangeMax"]) / max_int
+        channel_gains = np.ones(num_chan) * gain_factor
     else:
         device = fname.split(".")[-1]
         stream_kind = ""
@@ -590,15 +681,23 @@ def extract_stream_info(meta_file, meta):
     probe_port = meta.get("imDatPrb_port", None)
     probe_dock = meta.get("imDatPrb_dock", None)
 
+    # OneBox specific metadata
+    obx_slot = meta.get("imDatObx_slot", None)
+
     info = {}
     info["fname"] = fname
     info["meta"] = meta
-    for k in ("niSampRate", "imSampRate"):
+    for k in ("niSampRate", "imSampRate", "obSampRate"):
         if k in meta:
             info["sampling_rate"] = float(meta[k])
     info["num_chan"] = num_chan
 
-    info["sample_length"] = int(meta["fileSizeBytes"]) // 2 // num_chan
+    # Calculate sample_length from actual file size instead of metadata to handle stub/modified files
+    # The metadata fileSizeBytes may not match the actual .bin file (e.g., in test stub files)
+    # Original calculation (only correct for unmodified files):
+    # info["sample_length"] = int(meta["fileSizeBytes"]) // 2 // num_chan
+    actual_file_size = Path(meta_file).with_suffix(".bin").stat().st_size
+    info["sample_length"] = actual_file_size // 2 // num_chan  # 2 bytes per int16 sample
     info["gate_num"] = gate_num
     info["trigger_num"] = trigger_num
     info["device"] = device
@@ -613,8 +712,26 @@ def extract_stream_info(meta_file, meta):
     info["probe_slot"] = int(probe_slot) if probe_slot else None
     info["probe_port"] = int(probe_port) if probe_port else None
     info["probe_dock"] = int(probe_dock) if probe_dock else None
+    info["obx_slot"] = int(obx_slot) if obx_slot else None
 
-    if "nidq" in device:
+    # Add device index
+    if info.get("device_kind") == "imec":
+        info["device_index"] = info["device"].split("imec")[-1]
+    elif info.get("device_kind") == "obx":
+        info["device_index"] = info["device"].split("obx")[-1]
+    else:
+        info["device_index"] = ""  # TODO: Handle multi nidq case, maybe use meta["typeNiEnabled"]
+
+    # Define stream base on device_kind [imec|nidq|obx], device_index and stream_kind [ap|lf] for imec
+    # Stream format is "{device_kind}{device_index}.{stream_kind}"
+    device_kind = info["device_kind"]
+    device_index = info["device_index"]
+    stream_kind = f".{info['stream_kind']}" if info["stream_kind"] else ""
+    info["stream_name"] = f"{device_kind}{device_index}{stream_kind}"
+
+    # Separate analog and digital channels
+    if device_kind == "nidq":
+        # Note that we only handling the non-multiplexed channels here
         info["digital_channels"] = []
         info["analog_channels"] = [channel for channel in info["channel_names"] if not channel.startswith("XD")]
         # Digital/event channels are encoded within the digital word, so that will need more handling
@@ -626,4 +743,9 @@ def extract_stream_info(meta_file, meta):
                     info["digital_channels"].extend([f"XD{i}" for i in range(start, end + 1)])
                 else:
                     info["digital_channels"].append(f"XD{int(item)}")
+    elif device_kind == "obx":
+        # OneBox channel handling - focus on analog channels only as requested
+        info["digital_channels"] = [channel for channel in info["channel_names"] if channel.startswith("XD")]
+        info["analog_channels"] = [channel for channel in info["channel_names"] if channel.startswith("XA")]
+
     return info
