@@ -313,6 +313,10 @@ class TestConstructor(unittest.TestCase):
 
     def test__create_from_quantity_array_with_dtype(self):
         times = np.arange(10, dtype="f4") * pq.ms
+        # this step is required for NumPy 2.0 which now casts to float64 in the case either value/array
+        # is float64 even if not necessary
+        # https://numpy.org/devdocs/numpy_2_0_migration_guide.html
+        times = times.astype(dtype="f4")
         t_start = 0.0 * pq.s
         t_stop = 12.0 * pq.ms
         train1 = SpikeTrain(times, t_start=t_start, t_stop=t_stop)
@@ -343,6 +347,10 @@ class TestConstructor(unittest.TestCase):
 
     def test__create_from_quantity_array_no_start_stop_units_with_dtype(self):
         times = np.arange(10, dtype="f4") * pq.ms
+        # this step is required for NumPy 2.0 which now casts to float64 in the case either value/array
+        # is float64 even if not necessary
+        # https://numpy.org/devdocs/numpy_2_0_migration_guide.html
+        times = times.astype(dtype="f4")
         t_start = 0.0
         t_stop = 12.0
         train1 = SpikeTrain(times, t_start=t_start, t_stop=t_stop)
@@ -1143,7 +1151,7 @@ class TestMerge(unittest.TestCase):
         expected *= time_unit
         sorting = np.argsort(expected)
         expected = expected[sorting]
-        np.testing.assert_array_equal(result.times, expected)
+        np.testing.assert_array_equal(result.times.magnitude, expected.magnitude)
 
         # Make sure array annotations are merged correctly
         self.assertTrue("label" not in result.array_annotations)
