@@ -166,10 +166,10 @@ class TestAsciiSignalIO(unittest.TestCase):
         self.assertEqual(signal.units, pq.V)
         assert_array_equal(signal.times, [0.0, 1.0, 2.0, 3.0] * pq.s)
         assert_array_equal(signal.times.magnitude, [0.0, 1.0, 2.0, 3.0])
-        assert_array_equal(signal[0].magnitude, -64.8)
-        assert_array_equal(signal[1].magnitude, -64.6)
-        assert_array_equal(signal[2].magnitude, -64.3)
-        assert_array_equal(signal[3].magnitude, -66)
+        assert_array_almost_equal(signal[0].magnitude, -64.8, decimal=5)
+        assert_array_almost_equal(signal[1].magnitude, -64.6, decimal=5)
+        assert_array_almost_equal(signal[2].magnitude, -64.3, decimal=5)
+        assert_array_almost_equal(signal[3].magnitude, -66, decimal=5)
         assert_array_almost_equal(np.asarray(signal).flatten(), np.array([-64.8, -64.6, -64.3, -66]), decimal=5)
 
         os.remove(filename)
@@ -195,11 +195,11 @@ class TestAsciiSignalIO(unittest.TestCase):
         self.assertEqual(signal.units, pq.V)
         assert_array_equal(signal.times, [0.0, 1.0, 2.0, 3.0, 4.0] * pq.s)
         assert_array_equal(signal.times.magnitude, [0.0, 1.0, 2.0, 3.0, 4.0])
-        assert_array_equal(signal[0].magnitude, 0.5)
-        assert_array_equal(signal[1].magnitude, 0.6)
-        assert_array_equal(signal[2].magnitude, 0.7)
-        assert_array_equal(signal[3].magnitude, 0.8)
-        assert_array_equal(signal[4].magnitude, 1.4)
+        assert_array_almost_equal(signal[0].magnitude, 0.5, decimal=5)
+        assert_array_almost_equal(signal[1].magnitude, 0.6, decimal=5)
+        assert_array_almost_equal(signal[2].magnitude, 0.7, decimal=5)
+        assert_array_almost_equal(signal[3].magnitude, 0.8, decimal=5)
+        assert_array_almost_equal(signal[4].magnitude, 1.4, decimal=5)
         assert_array_almost_equal(np.asarray(signal).flatten(), np.array([0.5, 0.6, 0.7, 0.8, 1.4]), decimal=5)
 
         os.remove(filename)
