@@ -11,6 +11,7 @@ import numpy as np
 import quantities as pq
 
 from neo.io.blackrockio import BlackrockIO
+from neo.core import NeoReadWriteError
 
 from neo.test.iotest.common_io_test import BaseTestIO
 from neo.test.tools import assert_neo_object_is_compliant
@@ -25,11 +26,13 @@ except ImportError as err:
     HAVE_SCIPY = False
     SCIPY_ERR = err
 else:
-    if Version(scipy.version.version) < Version('0.8'):
+    if Version(scipy.version.version) < Version("0.8"):
         HAVE_SCIPY = False
-        SCIPY_ERR = ImportError("your scipy version is too old to support " +
-                                "MatlabIO, you need at least 0.8. " +
-                                "You have %s" % scipy.version.version)
+        SCIPY_ERR = ImportError(
+            "your scipy version is too old to support "
+            + "MatlabIO, you need at least 0.8. "
+            + "You have %s" % scipy.version.version
+        )
     else:
         HAVE_SCIPY = True
         SCIPY_ERR = None
@@ -37,17 +40,15 @@ else:
 
 class CommonTests(BaseTestIO, unittest.TestCase):
     ioclass = BlackrockIO
-    entities_to_download = [
-        'blackrock'
-    ]
+    entities_to_download = ["blackrock"]
     entities_to_test = [
-        'blackrock/FileSpec2.3001',
-        'blackrock/blackrock_2_1/l101210-001',
-        'blackrock/blackrock_3_0/file_spec_3_0'
+        "blackrock/FileSpec2.3001",
+        "blackrock/blackrock_2_1/l101210-001",
+        "blackrock/blackrock_3_0/file_spec_3_0",
     ]
 
     def test_load_waveforms(self):
-        filename = self.get_local_path('blackrock/FileSpec2.3001')
+        filename = self.get_local_path("blackrock/FileSpec2.3001")
         reader = BlackrockIO(filename=filename, verbose=False)
 
         bl = reader.read_block(load_waveforms=True)
@@ -58,12 +59,12 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         Test various inputs to BlackrockIO.read_block with version 2.3 file
         to check for parsing errors.
         """
-        filename = self.get_local_path('blackrock/FileSpec2.3001')
+        filename = self.get_local_path("blackrock/FileSpec2.3001")
         reader = BlackrockIO(filename=filename, verbose=False, nsx_to_load=5)
 
         # Assert IOError is raised when no Blackrock files are available
         with self.assertRaises(IOError):
-            reader2 = BlackrockIO(filename='nonexistent')
+            reader2 = BlackrockIO(filename="nonexistent")
 
         # Load data to maximum extent, one None is not given as list
         block = reader.read_block(load_waveforms=False)
@@ -78,7 +79,7 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         # this is valid in read_segment
         seg = reader.read_segment(seg_index=0, time_slice=buggy_slice, strict_slicing=False)
         # this raise an error
-        with self.assertRaises(AssertionError):
+        with self.assertRaises(ValueError):
             seg = reader.read_segment(seg_index=0, time_slice=buggy_slice, strict_slicing=True)
 
         lenb = len(seg.analogsignals[0])
@@ -93,12 +94,11 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         self.assertEqual(numspa, numspb)
 
         # test 4 Units
-        block = reader.read_block(load_waveforms=True,
-                                  signal_group_mode='split-all')
+        block = reader.read_block(load_waveforms=True, signal_group_mode="split-all")
 
         self.assertEqual(len(block.segments[0].analogsignals), 10)
-        #self.assertEqual(len(block.channel_indexes[-1].units), 4)
-        #self.assertEqual(len(block.channel_indexes[-1].units),
+        # self.assertEqual(len(block.channel_indexes[-1].units), 4)
+        # self.assertEqual(len(block.channel_indexes[-1].units),
         #                 len(block.segments[0].spiketrains))
 
         anasig = block.segments[0].analogsignals[0]
@@ -109,17 +109,17 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         Test various inputs to BlackrockIO.read_block with version 2.3 file
         to check for parsing errors.
         """
-        filename = self.get_local_path('blackrock/blackrock_2_1/l101210-001')
+        filename = self.get_local_path("blackrock/blackrock_2_1/l101210-001")
         reader = BlackrockIO(filename=filename, verbose=False, nsx_to_load=5)
 
         # Assert IOError is raised when no Blackrock files are available
         with self.assertRaises(IOError):
-            reader2 = BlackrockIO(filename='nonexistent')
+            reader2 = BlackrockIO(filename="nonexistent")
         # with self.assertRaises(IOError):
         #     reader2 = BlackrockIO(filename=filename, nev_override='nonexistent')
 
         # Load data to maximum extent, one None is not given as list
-        block = reader.read_block(load_waveforms=False, signal_group_mode='split-all')
+        block = reader.read_block(load_waveforms=False, signal_group_mode="split-all")
         lena = len(block.segments[0].analogsignals[0])
         numspa = len(block.segments[0].spiketrains[0])
 
@@ -131,7 +131,7 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         # This is valid in read_segment
         seg = reader.read_segment(seg_index=0, time_slice=buggy_slice, strict_slicing=False)
         # this raise error
-        with self.assertRaises(AssertionError):
+        with self.assertRaises(ValueError):
             seg = reader.read_segment(seg_index=0, time_slice=buggy_slice, strict_slicing=True)
 
         lenb = len(seg.analogsignals[0])
@@ -146,13 +146,14 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         self.assertEqual(numspa, numspb)
 
         # test 4 Units
-        block = reader.read_block(load_waveforms=True,
-                                  signal_group_mode='split-all',
-                                  )#units_group_mode='all-in-one')
+        block = reader.read_block(
+            load_waveforms=True,
+            signal_group_mode="split-all",
+        )  # units_group_mode='all-in-one')
 
         self.assertEqual(len(block.segments[0].analogsignals), 96)
-        #self.assertEqual(len(block.channel_indexes[-1].units), 218)
-        #self.assertEqual(len(block.channel_indexes[-1].units),
+        # self.assertEqual(len(block.channel_indexes[-1].units), 218)
+        # self.assertEqual(len(block.channel_indexes[-1].units),
         #                 len(block.segments[0].spiketrains))
         anasig = block.segments[0].analogsignals[0]
         self.assertIsNotNone(anasig.file_origin)
@@ -161,19 +162,17 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         """
         Test if multiple nsx signals can be loaded at the same time.
         """
-        filename = self.get_local_path('blackrock/blackrock_2_1/l101210-001')
-        reader = BlackrockIO(filename=filename, verbose=False, nsx_to_load='all')
+        filename = self.get_local_path("blackrock/blackrock_2_1/l101210-001")
+        reader = BlackrockIO(filename=filename, verbose=False, nsx_to_load="all")
 
         # number of different sampling rates corresponds to number of nsx signals, because
         # single nsx contains only signals of identical sampling rate
         block = reader.read_block(load_waveforms=False)
-        sampling_rates = np.unique(
-            [a.sampling_rate.rescale('Hz') for a in block.filter(objects='AnalogSignal')])
+        sampling_rates = np.unique([a.sampling_rate.rescale("Hz") for a in block.filter(objects="AnalogSignal")])
         self.assertEqual(len(sampling_rates), 2)
 
         segment = reader.read_segment()
-        sampling_rates = np.unique(
-            [a.sampling_rate.rescale('Hz') for a in segment.filter(objects='AnalogSignal')])
+        sampling_rates = np.unique([a.sampling_rate.rescale("Hz") for a in segment.filter(objects="AnalogSignal")])
         self.assertEqual(len(sampling_rates), 2)
 
         # load only ns5
@@ -201,7 +200,7 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         self.assertEqual(seg.analogsignals[1].shape, (109224, 96))
 
         # load only ns5
-        reader = BlackrockIO(filename=filename, nsx_to_load='max')
+        reader = BlackrockIO(filename=filename, nsx_to_load="max")
         seg = reader.read_segment()
         self.assertEqual(len(seg.analogsignals), 1)
         self.assertEqual(seg.analogsignals[0].shape, (109224, 96))
@@ -216,64 +215,61 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         The function tests LFPs, spike times, and digital events.
         """
 
-        dirname = self.get_local_path('blackrock/blackrock_2_1/l101210-001')
+        dirname = self.get_local_path("blackrock/blackrock_2_1/l101210-001")
         # First run with parameters for ns5, then run with correct parameters for ns2
-        parameters = [('blackrock/blackrock_2_1/l101210-001_nev-02_ns5.mat',
-                       {'nsx_to_load': 5, 'nev_override': '-'.join([dirname, '02'])}),
-                      ('blackrock/blackrock_2_1/l101210-001.mat', {'nsx_to_load': 2})]
+        parameters = [
+            (
+                "blackrock/blackrock_2_1/l101210-001_nev-02_ns5.mat",
+                {"nsx_to_load": 5, "nev_override": "-".join([dirname, "02"])},
+            ),
+            ("blackrock/blackrock_2_1/l101210-001.mat", {"nsx_to_load": 2}),
+        ]
         for index, param in enumerate(parameters):
             # Load data from matlab generated files
             ml = scipy.io.loadmat(self.get_local_path(param[0]))
-            lfp_ml = ml['lfp']  # (channel x time) LFP matrix
-            ts_ml = ml['ts']  # spike time stamps
-            elec_ml = ml['el']  # spike electrodes
-            unit_ml = ml['un']  # spike unit IDs
-            wf_ml = ml['wf']  # waveforms
-            mts_ml = ml['mts']  # marker time stamps
-            mid_ml = ml['mid']  # marker IDs
+            lfp_ml = ml["lfp"]  # (channel x time) LFP matrix
+            ts_ml = ml["ts"]  # spike time stamps
+            elec_ml = ml["el"]  # spike electrodes
+            unit_ml = ml["un"]  # spike unit IDs
+            wf_ml = ml["wf"]  # waveforms
+            mts_ml = ml["mts"]  # marker time stamps
+            mid_ml = ml["mid"]  # marker IDs
 
             # Load data from original data files using the Neo BlackrockIO
-            session = BlackrockIO(
-                dirname,
-                verbose=False, **param[1])
-            block = session.read_block(load_waveforms=True, signal_group_mode='split-all')
+            session = BlackrockIO(dirname, verbose=False, **param[1])
+            block = session.read_block(load_waveforms=True, signal_group_mode="split-all")
             # Check if analog data are equal
             self.assertGreater(len(block.groups), 0)
 
             # Check if spikes are equal
             self.assertEqual(len(block.segments), 1)
             for st_i in block.segments[0].spiketrains:
-                channelid = st_i.annotations['channel_id']
-                unitid = st_i.annotations['unit_id']
+                channelid = st_i.annotations["channel_id"]
+                unitid = st_i.annotations["unit_id"]
 
                 # Compare waveforms
-                matlab_wf = wf_ml[np.nonzero(
-                    np.logical_and(elec_ml == channelid, unit_ml == unitid)), :][0]
+                matlab_wf = wf_ml[np.nonzero(np.logical_and(elec_ml == channelid, unit_ml == unitid)), :][0]
                 # Atleast_2d as correction for waveforms that are saved
                 # in single dimension in SpikeTrain
                 # because only one waveform is available
                 assert_equal(np.atleast_2d(np.squeeze(st_i.waveforms).magnitude), matlab_wf)
 
                 # Compare spike timestamps
-                matlab_spikes = ts_ml[np.nonzero(
-                    np.logical_and(elec_ml == channelid, unit_ml == unitid))]
+                matlab_spikes = ts_ml[np.nonzero(np.logical_and(elec_ml == channelid, unit_ml == unitid))]
                 # Going sure that unit is really seconds and not 1/30000 seconds
-                if (not st_i.units == pq.CompoundUnit("1.0/{} * s".format(30000))) and \
-                        st_i.units == pq.s:
+                if (not st_i.units == pq.CompoundUnit("1.0/{} * s".format(30000))) and st_i.units == pq.s:
                     st_i = np.round(st_i.base * 30000).astype(int)
                 assert_equal(st_i, matlab_spikes)
 
             # Check if digital input port events are equal
             self.assertGreater(len(block.segments[0].events), 0)
             for ea_i in block.segments[0].events:
-                if ea_i.name == 'digital_input_port':
+                if ea_i.name == "digital_input_port":
                     # Get all digital event IDs in this recording
                     marker_ids = set(ea_i.labels)
                     for marker_id in marker_ids:
-                        python_digievents = np.round(
-                            ea_i.times.base[ea_i.labels == marker_id] * 30000).astype(int)
-                        matlab_digievents = mts_ml[
-                            np.nonzero(mid_ml == int(marker_id))]
+                        python_digievents = np.round(ea_i.times.base[ea_i.labels == marker_id] * 30000).astype(int)
+                        matlab_digievents = mts_ml[np.nonzero(mid_ml == int(marker_id))]
                         assert_equal(python_digievents, matlab_digievents)
 
                         # Note: analog input events are not yet supported
@@ -284,15 +280,15 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         """
 
         # Path to nev that will fail
-        filename_nev_fail = self.get_local_path('blackrock/segment/ResetFail/reset_fail')
+        filename_nev_fail = self.get_local_path("blackrock/segment/ResetFail/reset_fail")
         # Path to nsX and nev that will NOT fail
-        filename = self.get_local_path('blackrock/segment/ResetCorrect/reset')
+        filename = self.get_local_path("blackrock/segment/ResetCorrect/reset")
 
         # Warning filter needs to be set to always before first occurrence of this warning
         warnings.simplefilter("always", UserWarning)
 
         # This fails, because in the nev there is no way to separate two segments
-        with self.assertRaises(AssertionError):
+        with self.assertRaises(NeoReadWriteError):
             reader = BlackrockIO(filename=filename, nsx_to_load=2, nev_override=filename_nev_fail)
 
         # The correct file will issue a warning because a reset has occurred
@@ -301,8 +297,7 @@ class CommonTests(BaseTestIO, unittest.TestCase):
             reader = BlackrockIO(filename=filename, nsx_to_load=2)
             self.assertGreaterEqual(len(w), 1)
             messages = [str(warning.message) for warning in w if warning.category == UserWarning]
-            self.assertIn("Detected 1 undocumented segments within nev data after "
-                          "timestamps [5451].", messages)
+            self.assertIn("Detected 1 undocumented segments within nev data after " "timestamps [5451].", messages)
 
         # Manually reset warning filter in order to not show too many warnings afterwards
         warnings.simplefilter("default")
@@ -328,8 +323,7 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         self.assertEqual(block.segments[1].spiketrains[0].t_stop, 3.9842)
 
         # Each segment must have the same number of analogsignals
-        self.assertEqual(len(block.segments[0].analogsignals),
-                         len(block.segments[1].analogsignals))
+        self.assertEqual(len(block.segments[0].analogsignals), len(block.segments[1].analogsignals))
 
         # Length of analogsignals as created
         self.assertEqual(len(block.segments[0].analogsignals[0][:]), 4020)
@@ -341,23 +335,21 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         """
 
         # Path to nev that has spikes that don't fit nsX segment
-        filename_nev_outside_seg = self.get_local_path(
-            'blackrock/segment/PauseSpikesOutside/pause_spikes_outside_seg')
+        filename_nev_outside_seg = self.get_local_path("blackrock/segment/PauseSpikesOutside/pause_spikes_outside_seg")
         # Path to nsX and nev that are correct
-        filename = self.get_local_path('blackrock/segment/PauseCorrect/pause_correct')
+        filename = self.get_local_path("blackrock/segment/PauseCorrect/pause_correct")
 
         # This issues a warning, because there are spikes a long time after the last segment
         # And another one because there are spikes between segments
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter("always")
-            reader = BlackrockIO(filename=filename, nsx_to_load=2,
-                                 nev_override=filename_nev_outside_seg)
+            reader = BlackrockIO(filename=filename, nsx_to_load=2, nev_override=filename_nev_outside_seg)
             self.assertGreaterEqual(len(w), 2)
 
             # Check that warnings are correct
             messages = [str(warning.message) for warning in w if warning.category == UserWarning]
-            self.assertIn('Spikes outside any segment. Detected on segment #1', messages)
-            self.assertIn('Spikes 0.0776s after last segment.', messages)
+            self.assertIn("Spikes outside any segment. Detected on segment #1", messages)
+            self.assertIn("Spikes 0.0776s after last segment.", messages)
 
         block = reader.read_block(load_waveforms=False, signal_group_mode="split-all")
 
@@ -381,17 +373,14 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         # whose length is caused by the additional spike
         self.assertEqual(block.segments[0].analogsignals[0].t_stop, 4.0)
         self.assertEqual(block.segments[1].analogsignals[0].t_start, 31.0087)
-        self.assertAlmostEqual(block.segments[1].analogsignals[0].t_stop.magnitude, 35.0087,
-                               places=6)
+        self.assertAlmostEqual(block.segments[1].analogsignals[0].t_stop.magnitude, 35.0087, places=6)
         self.assertEqual(block.segments[0].spiketrains[0].t_start, 0.0)
-        self.assertAlmostEqual(block.segments[0].spiketrains[0].t_stop.magnitude, 15.83916667,
-                               places=8)
+        self.assertAlmostEqual(block.segments[0].spiketrains[0].t_stop.magnitude, 15.83916667, places=8)
         self.assertEqual(block.segments[1].spiketrains[0].t_start, 31.0087)
         self.assertEqual(block.segments[1].spiketrains[0].t_stop, 35.0863)
 
         # Each segment has same number of analogsignals
-        self.assertEqual(len(block.segments[0].analogsignals),
-                         len(block.segments[1].analogsignals))
+        self.assertEqual(len(block.segments[0].analogsignals), len(block.segments[1].analogsignals))
 
         # Analogsignals have exactly 4000 samples
         self.assertEqual(len(block.segments[0].analogsignals[0][:]), 4000)
@@ -414,22 +403,19 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         self.assertEqual(block.segments[0].analogsignals[0].t_start, 0.0)
         self.assertEqual(block.segments[0].analogsignals[0].t_stop, 4.0)
         self.assertEqual(block.segments[1].analogsignals[0].t_start, 31.0087)
-        self.assertAlmostEqual(block.segments[1].analogsignals[0].t_stop.magnitude, 35.0087,
-                               places=6)
+        self.assertAlmostEqual(block.segments[1].analogsignals[0].t_stop.magnitude, 35.0087, places=6)
         self.assertEqual(block.segments[0].spiketrains[0].t_start, 0.0)
         self.assertEqual(block.segments[0].spiketrains[0].t_stop, 4.0)
         self.assertEqual(block.segments[1].spiketrains[0].t_start, 31.0087)
-        self.assertAlmostEqual(block.segments[1].spiketrains[0].t_stop.magnitude, 35.0087,
-                               places=6)
+        self.assertAlmostEqual(block.segments[1].spiketrains[0].t_stop.magnitude, 35.0087, places=6)
 
         # Each segment has same number of analogsignals
-        self.assertEqual(len(block.segments[0].analogsignals),
-                         len(block.segments[1].analogsignals))
+        self.assertEqual(len(block.segments[0].analogsignals), len(block.segments[1].analogsignals))
 
         # ns2 was created in such a way that all analogsignals have 4000 samples
         self.assertEqual(len(block.segments[0].analogsignals[0][:]), 4000)
         self.assertEqual(len(block.segments[1].analogsignals[0][:]), 4000)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
