@@ -8,14 +8,13 @@ from neo.io import RawBinarySignalIO
 from neo.test.iotest.common_io_test import BaseTestIO
 
 
-class TestRawBinarySignalIO(BaseTestIO, unittest.TestCase, ):
+class TestRawBinarySignalIO(
+    BaseTestIO,
+    unittest.TestCase,
+):
     ioclass = RawBinarySignalIO
-    entities_to_download = [
-        'rawbinarysignal'
-    ]
-    entities_to_test = [
-        'rawbinarysignal/File_rawbinary_10kHz_2channels_16bit.raw'
-    ]
+    entities_to_download = ["rawbinarysignal"]
+    entities_to_test = ["rawbinarysignal/File_rawbinary_10kHz_2channels_16bit.raw"]
 
     # Skip  this test because there are not mechanisim
     # in neo.tests.iotests to set parameters for the ioclass
