@@ -19,6 +19,9 @@ __test__ = False
 
 import logging
 import unittest
+import importlib.util
+import warnings
+import os
 
 from neo.utils.datasets import download_dataset, get_local_testing_data_folder, default_testing_repo
 
@@ -26,12 +29,17 @@ from neo.test.rawiotest.tools import can_use_network
 
 from neo.test.rawiotest import rawio_compliance as compliance
 
-try:
-    import datalad
-
+datalad_spec = importlib.util.find_spec("datalad")
+if datalad_spec is not None:
     HAVE_DATALAD = True
-except:
+else:
     HAVE_DATALAD = False
+    # pytest skip doesn't explain why we are skipping.
+    # raise error if in CI to prevent tests from spuriously skipping and appearing
+    # as passing.
+    if os.environ.get("GITHUB_ACTIONS") == "true":
+        raise RuntimeError("Datalad is required for running the CI.")
+
 
 # url_for_tests = "https://portal.g-node.org/neo/" #This is the old place
 repo_for_test = default_testing_repo
