@@ -8,15 +8,18 @@ from neo.rawio.edfrawio import EDFRawIO
 from neo.test.rawiotest.common_rawio_test import BaseTestRawIO
 
 
-class TestExampleRawIO(BaseTestRawIO, unittest.TestCase, ):
+class TestExampleRawIO(
+    BaseTestRawIO,
+    unittest.TestCase,
+):
     rawioclass = EDFRawIO
-    entities_to_download = ['edf']
+    entities_to_download = ["edf"]
     entities_to_test = [
-        'edf/edf+C.edf',
+        "edf/edf+C.edf",
     ]
 
     def test_context_handler(self):
-        filename = self.get_local_path('edf/edf+C.edf')
+        filename = self.get_local_path("edf/edf+C.edf")
         with EDFRawIO(filename) as io:
             io.parse_header()
 
@@ -25,7 +28,7 @@ class TestExampleRawIO(BaseTestRawIO, unittest.TestCase, ):
             pass
 
     def test_close(self):
-        filename = self.get_local_path('edf/edf+C.edf')
+        filename = self.get_local_path("edf/edf+C.edf")
 
         # Open file and close it again
         io1 = EDFRawIO(filename)
