@@ -5,13 +5,14 @@ from neo.rawio.elanrawio import ElanRawIO
 from neo.test.rawiotest.common_rawio_test import BaseTestRawIO
 
 
-class TestElanRawIO(BaseTestRawIO, unittest.TestCase, ):
+class TestElanRawIO(
+    BaseTestRawIO,
+    unittest.TestCase,
+):
     rawioclass = ElanRawIO
-    entities_to_test = [
-        'elan/File_elan_1.eeg'
-    ]
+    entities_to_test = ["elan/File_elan_1.eeg"]
     entities_to_download = [
-        'elan',
+        "elan",
     ]
 
 
