@@ -1,5 +1,4 @@
 import unittest
-import os
 
 from neo.rawio.maxwellrawio import MaxwellRawIO, auto_install_maxwell_hdf5_compression_plugin
 from neo.test.rawiotest.common_rawio_test import BaseTestRawIO
@@ -9,6 +8,7 @@ class TestMaxwellRawIO(
     BaseTestRawIO,
     unittest.TestCase,
 ):
+
     rawioclass = MaxwellRawIO
     entities_to_download = ["maxwell"]
     entities_to_test = files_to_test = [
@@ -18,7 +18,6 @@ class TestMaxwellRawIO(
 
     def setUp(self):
         auto_install_maxwell_hdf5_compression_plugin(force_download=False)
-        BaseTestRawIO.setUp(self)
 
 
 if __name__ == "__main__":
