@@ -1,11 +1,13 @@
+import datetime
 import unittest
 
 import os
 import numpy as np
+import re
 
 from neo.rawio.neuralynxrawio.neuralynxrawio import NeuralynxRawIO
 from neo.rawio.neuralynxrawio.nlxheader import NlxHeader
-from neo.rawio.neuralynxrawio.ncssections import NcsSection, NcsSections, NcsSectionsFactory
+from neo.rawio.neuralynxrawio.ncssections import AcqType, NcsSection, NcsSections, NcsSectionsFactory
 from neo.test.rawiotest.common_rawio_test import BaseTestRawIO
 
 import logging
@@ -29,6 +31,7 @@ class TestNeuralynxRawIO(
         "neuralynx/Cheetah_v5.6.3/original_data",
         "neuralynx/Cheetah_v5.7.4/original_data",
         "neuralynx/Cheetah_v6.3.2/incomplete_blocks",
+        "neuralynx/two_streams_different_header_encoding",
     ]
 
     def test_scan_ncs_files(self):
@@ -173,40 +176,120 @@ class TestNeuralynxRawIO(
         self.assertEqual(len(rawio.header["spike_channels"]), 8)
         self.assertEqual(len(rawio.header["event_channels"]), 0)
 
+    def test_directory_in_data_folder(self):
+        """
+        Test that directories inside the data folder are properly ignored
+        and don't cause errors during parsing.
+        """
+        import tempfile
+        import shutil
 
-class TestNcsRecordingType(TestNeuralynxRawIO, unittest.TestCase):
+        # Use existing test data directory
+        dname = self.get_local_path("neuralynx/Cheetah_v5.6.3/original_data/")
+
+        # Create a temporary copy to avoid modifying test data
+        with tempfile.TemporaryDirectory() as temp_dir:
+            temp_data_dir = os.path.join(temp_dir, "test_data")
+            shutil.copytree(dname, temp_data_dir)
+
+            # Create a subdirectory inside the test data
+            test_subdir = os.path.join(temp_data_dir, "raw fscv data with all recorded ch")
+            os.makedirs(test_subdir, exist_ok=True)
+
+            # Create some files in the subdirectory to make it more realistic
+            with open(os.path.join(test_subdir, "some_file.txt"), "w") as f:
+                f.write("test file content")
+
+            # This should not raise an error despite the directory presence
+            rawio = NeuralynxRawIO(dirname=temp_data_dir)
+            rawio.parse_header()
+
+            # Verify that the reader still works correctly
+            self.assertEqual(rawio._nb_segment, 2)
+            self.assertEqual(len(rawio.ncs_filenames), 2)
+            self.assertEqual(len(rawio.nev_filenames), 1)
+            sigHdrs = rawio.header["signal_channels"]
+            self.assertEqual(sigHdrs.size, 2)
+            self.assertEqual(len(rawio.header["spike_channels"]), 8)
+            self.assertEqual(len(rawio.header["event_channels"]), 2)
+
+    def test_two_streams_different_header_encoding(self):
+        """
+        Test that streams are correctly differentiated based on filter parameters.
+        This dataset contains eye-tracking and ephys channels with different filter settings.
+        """
+        from pathlib import Path
+
+        # Get the path using the same machinery as other tests
+        dname = self.get_local_path("neuralynx/two_streams_different_header_encoding")
+
+        # Test with Path object (as shown in user's notebook)
+        rawio = NeuralynxRawIO(dirname=Path(dname))
+        rawio.parse_header()
+
+        # Should have 2 streams due to different filter configurations
+        self.assertEqual(rawio.signal_streams_count(), 2)
+
+        # Check stream names follow the new naming convention
+        stream_names = [rawio.header["signal_streams"][i][0] for i in range(rawio.signal_streams_count())]
+
+        # Stream names should include sampling rate (Hz), voltage range (mV), and DSP filter ID
+        for stream_name in stream_names:
+            self.assertRegex(stream_name, r"stream\d+_\d+Hz_\d+mVRange_DSPFilter\d+")
+
+        # Verify we have the expected streams:
+        # - Eye-tracking channels (CSC145, CSC146): 32000Hz, 100mV range, low-cut disabled
+        # - Ephys channel (CSC76): 32000Hz, 1mV range, low-cut enabled
+        expected_names = {"stream0_32000Hz_100mVRange_DSPFilter0", "stream1_32000Hz_1mVRange_DSPFilter1"}
+        self.assertEqual(set(stream_names), expected_names)
+
+        # Verify DSP filter configurations are stored (private for now)
+        self.assertTrue(hasattr(rawio, "_dsp_filter_configurations"))
+        self.assertEqual(len(rawio._dsp_filter_configurations), 2)
+
+        # Verify filter 0 (eye-tracking): low-cut disabled
+        filter_0 = rawio._dsp_filter_configurations[0]
+        self.assertFalse(filter_0.get("DSPLowCutFilterEnabled", True))
+
+        # Verify filter 1 (ephys): low-cut enabled
+        filter_1 = rawio._dsp_filter_configurations[1]
+        self.assertTrue(filter_1.get("DSPLowCutFilterEnabled", False))
+
+
+class TestNcsRecordingType(BaseTestRawIO, unittest.TestCase):
     """
     Test of decoding of NlxHeader for type of recording.
     """
 
+    rawioclass = NeuralynxRawIO
     entities_to_test = []
 
     ncsTypeTestFiles = [
-        ("neuralynx/Cheetah_v4.0.2/original_data/CSC14_trunc.Ncs", "PRE4"),
-        ("neuralynx/Cheetah_v5.4.0/original_data/CSC5_trunc.Ncs", "DIGITALLYNX"),
-        ("neuralynx/Cheetah_v5.5.1/original_data/STet3a.nse", "DIGITALLYNXSX"),
-        ("neuralynx/Cheetah_v5.5.1/original_data/Tet3a.ncs", "DIGITALLYNXSX"),
-        ("neuralynx/Cheetah_v5.6.3/original_data/CSC1.ncs", "DIGITALLYNXSX"),
-        ("neuralynx/Cheetah_v5.6.3/original_data/TT1.ntt", "DIGITALLYNXSX"),
-        ("neuralynx/Cheetah_v5.7.4/original_data/CSC1.ncs", "DIGITALLYNXSX"),
-        ("neuralynx/Cheetah_v6.3.2/incomplete_blocks/CSC1_reduced.ncs", "DIGITALLYNXSX"),
-        ("neuralynx/Pegasus_v2.1.1/Events_0008.nev", "ATLAS"),
+        ("neuralynx/Cheetah_v4.0.2/original_data/CSC14_trunc.Ncs", AcqType.PRE4),
+        ("neuralynx/Cheetah_v5.4.0/original_data/CSC5_trunc.Ncs", AcqType.DIGITALLYNX),
+        ("neuralynx/Cheetah_v5.5.1/original_data/STet3a.nse", AcqType.DIGITALLYNXSX),
+        ("neuralynx/Cheetah_v5.5.1/original_data/Tet3a.ncs", AcqType.DIGITALLYNXSX),
+        ("neuralynx/Cheetah_v5.6.3/original_data/CSC1.ncs", AcqType.DIGITALLYNXSX),
+        ("neuralynx/Cheetah_v5.6.3/original_data/TT1.ntt", AcqType.DIGITALLYNXSX),
+        ("neuralynx/Cheetah_v5.7.4/original_data/CSC1.ncs", AcqType.DIGITALLYNXSX),
+        ("neuralynx/Cheetah_v6.3.2/incomplete_blocks/CSC1_reduced.ncs", AcqType.DIGITALLYNXSX),
+        ("neuralynx/Pegasus_v2.1.1/Events_0008.nev", AcqType.ATLAS),
     ]
 
     def test_recording_types(self):
 
         for typeTest in self.ncsTypeTestFiles:
-
             filename = self.get_local_path(typeTest[0])
             hdr = NlxHeader(filename)
             self.assertEqual(hdr.type_of_recording(), typeTest[1])
 
 
-class TestNcsSectionsFactory(TestNeuralynxRawIO, unittest.TestCase):
+class TestNcsSectionsFactory(BaseTestRawIO, unittest.TestCase):
     """
     Test building NcsBlocks for files of different revisions.
     """
 
+    rawioclass = NeuralynxRawIO
     entities_to_test = []
 
     def test_ncsblocks_partial(self):
@@ -323,11 +406,12 @@ class TestNcsSectionsFactory(TestNeuralynxRawIO, unittest.TestCase):
         self.assertTrue(NcsSectionsFactory._verifySectionsStructure(data1, nb1))
 
 
-class TestNcsSections(TestNeuralynxRawIO, unittest.TestCase):
+class TestNcsSections(BaseTestRawIO, unittest.TestCase):
     """
     Test building NcsBlocks for files of different revisions.
     """
 
+    rawioclass = NeuralynxRawIO
     entities_to_test = []
 
     def test_equality(self):
@@ -361,7 +445,9 @@ class TestNcsSections(TestNeuralynxRawIO, unittest.TestCase):
         self.assertNotEqual(ns0, ns1)
 
 
-class TestNlxHeader(TestNeuralynxRawIO, unittest.TestCase):
+class TestNlxHeader(BaseTestRawIO, unittest.TestCase):
+    rawioclass = NeuralynxRawIO
+
     def test_no_date_time(self):
         filename = self.get_local_path("neuralynx/NoDateHeader/NoDateHeader.nev")
 
@@ -374,15 +460,108 @@ class TestNlxHeader(TestNeuralynxRawIO, unittest.TestCase):
         self.assertEqual(hdr["ApplicationName"], "Pegasus")
         self.assertEqual(hdr["FileType"], "Event")
 
+    def test_neuraview2(self):
+        filename = self.get_local_path("neuralynx/Neuraview_v2/original_data/NeuraviewEventMarkers-sample.nev")
+        hdr = NlxHeader(filename)
+
+        self.assertEqual(datetime.datetime(2015, 12, 14, 15, 58, 32), hdr["recording_opened"])
+        self.assertEqual(datetime.datetime(2015, 12, 14, 15, 58, 32), hdr["recording_closed"])
+
+    # left in for possible future header tests
+
+    # left in for possible future header tests
+    def check_dateutil_parse(self, hdrTxt, openPat, closePat, openDate, closeDate):
+        import dateutil
+
+        mtch = openPat.search(hdrTxt)
+        self.assertIsNotNone(mtch)
+        dt = mtch.groupdict()
+        date = dateutil.parser.parse(f"{dt['date']} {dt['time']}")
+        self.assertEqual(openDate, date)
+        if closePat is not None:
+            mtch = closePat.search(hdrTxt)
+            self.assertIsNotNone(mtch)
+            dt = mtch.groupdict()
+            date = dateutil.parser.parse(f"{dt['date']} {dt['time']}")
+            self.assertEqual(closeDate, date)
+
+    def test_datetime_parsing(self):
+        # neuraview2
+        filename = self.get_local_path("neuralynx/Neuraview_v2/original_data/NeuraviewEventMarkers-sample.nev")
+        txt_header = NlxHeader.get_text_header(filename)
+        self.check_dateutil_parse(
+            txt_header,
+            NlxHeader._openDatetime1_pat,
+            NlxHeader._closeDatetime1_pat,
+            datetime.datetime(2015, 12, 14, 15, 58, 32),
+            datetime.datetime(2015, 12, 14, 15, 58, 32),
+        )
+        hdr = NlxHeader(filename)
+        self.assertEqual(datetime.datetime(2015, 12, 14, 15, 58, 32), hdr["recording_opened"])
+        self.assertEqual(datetime.datetime(2015, 12, 14, 15, 58, 32), hdr["recording_closed"])
+
+        # Cheetah 5.7.4 'inProps'
+        filename = self.get_local_path("neuralynx/Cheetah_v5.7.4/original_data/CSC1.ncs")
+        txt_header = NlxHeader.get_text_header(filename)
+        self.check_dateutil_parse(
+            txt_header,
+            NlxHeader._openDatetime2_pat,
+            NlxHeader._closeDatetime2_pat,
+            datetime.datetime(2017, 2, 16, 17, 56, 4),
+            datetime.datetime(2017, 2, 16, 18, 1, 18),
+        )
+        hdr = NlxHeader(filename)
+        self.assertEqual(datetime.datetime(2017, 2, 16, 17, 56, 4), hdr["recording_opened"])
+        self.assertEqual(datetime.datetime(2017, 2, 16, 18, 1, 18), hdr["recording_closed"])
+
+        # Cheetah 4.0.2
+        filename = self.get_local_path("neuralynx/Cheetah_v4.0.2/original_data/CSC14_trunc.Ncs")
+        txt_header = NlxHeader.get_text_header(filename)
+        self.check_dateutil_parse(
+            txt_header, NlxHeader._openDatetime1_pat, None, datetime.datetime(2003, 10, 4, 10, 3, 0, 578000), None
+        )
+        hdr = NlxHeader(filename)
+        self.assertEqual(datetime.datetime(2003, 10, 4, 10, 3, 0, 578000), hdr["recording_opened"])
+        self.assertIsNone(hdr.get("recording_closed"))
+
+        # Cheetah 5.4.0 'openClosedInHeader'
+        filename = self.get_local_path("neuralynx/Cheetah_v5.4.0/original_data/CSC5_trunc.Ncs")
+        txt_header = NlxHeader.get_text_header(filename)
+        self.check_dateutil_parse(
+            txt_header,
+            NlxHeader._openDatetime1_pat,
+            NlxHeader._closeDatetime1_pat,
+            datetime.datetime(2001, 1, 1, 0, 0, 0, 0),
+            datetime.datetime(2001, 1, 1, 0, 0, 0, 0),
+        )
+        hdr = NlxHeader(filename)
+        self.assertEqual(datetime.datetime(2001, 1, 1, 0, 0, 0, 0), hdr["recording_opened"])
+        self.assertEqual(datetime.datetime(2001, 1, 1, 0, 0, 0, 0), hdr["recording_closed"])
+
+    def test_filename_prop(self):
+        # neuraview2
+        filename = self.get_local_path("neuralynx/Neuraview_v2/original_data/NeuraviewEventMarkers-sample.nev")
+        hdr = NlxHeader(filename)
+        self.assertEqual(
+            r"L:\McHugh Lab\Recording\2015-06-24_18-05-11\NeuraviewEventMarkers-20151214_SleepScore.nev",
+            hdr["OriginalFileName"],
+        )
+
+        # Cheetah 5.7.4 'inProps'
+        filename = self.get_local_path("neuralynx/Cheetah_v5.7.4/original_data/CSC1.ncs")
+        hdr = NlxHeader(filename)
+        self.assertEqual(r"C:\CheetahData\2017-02-16_17-55-55\CSC1.ncs", hdr["OriginalFileName"])
+
+        # Cheetah 4.0.2
+        filename = self.get_local_path("neuralynx/Cheetah_v4.0.2/original_data/CSC14_trunc.Ncs")
+        hdr = NlxHeader(filename)
+        self.assertEqual(r"D:\Cheetah_Data\2003-10-4_10-2-58\CSC14.Ncs", hdr["OriginalFileName"])
+
+        # Cheetah 5.4.0
+        filename = self.get_local_path("neuralynx/Cheetah_v5.4.0/original_data/CSC5_trunc.Ncs")
+        hdr = NlxHeader(filename)
+        self.assertEqual(r"C:\CheetahData\2000-01-01_00-00-00\CSC5.ncs", hdr["OriginalFileName"])
+
 
 if __name__ == "__main__":
     unittest.main()
-
-    # test = TestNeuralynxRawIO()
-    # test.test_scan_ncs_files()
-    # test.test_exclude_filenames()
-    # test.test_include_filenames()
-
-    # test = TestNcsSectionsFactory()
-    # test.test_ncsblocks_partial()
-    # test.test_build_given_actual_frequency()
